<?php

namespace App\Http\Controllers\Attendence;

use App\Http\Controllers\Controller;
use App\Models\Attendence;
use App\Models\Employee;
use App\Models\EmployeeMonths;
use App\Models\Month;
use DateTime;
use Illuminate\Http\Request;
use PDF;

class AttendenceController extends Controller
{
    
    public function __construct()
    {
        $this->middleware(['auth']);
        $this->middleware(['role']);
    }
    

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $datefull = new DateTime();
        $current_month = date_format($datefull,"m-Y");
        $Month = new MonthController();
        $isMonthcreated = Month::where("month_year", $current_month)->first();
        $empolyee_month = EmployeeMonths::where('month_year', $current_month)->get();
        if(!$isMonthcreated):
           $Month->createMonthAllEmployees();
        endif;

        $data = Employee::paginate(20);
        return view('attendence.all_employee')->with(['data'=> $data, 'month'=>$current_month]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function currentMonth(Request $request, $id, $month)
    {   $empolyee = Employee::withTrashed()->where('id', $id)->first();
        $empolyee_month = EmployeeMonths::where('employee_id', $id)->where('month_year', $month)->first();
        $data = Attendence::where('employee_id', $id)
                           ->where('month_year', $month)
                           ->get();
         if($request->has('download'))
        {
            $pdf = PDF::loadView('attendence.single_month_pdf',['data'=>$data,'employee'=>$empolyee, 'month' => $month, "emp_month"=>$empolyee_month]);
            return $pdf->download();
        }
        return view('attendence.single_month')->with(['data'=>$data,'employee'=>$empolyee, 'month' => $month, "emp_month"=>$empolyee_month]);
    }

     /**
     * Show the form for creating a new resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function attendenceToday()
    {
        //
        $timestamp=new DateTime();
        
        $date = $timestamp->format("Y-m-d");
        $data = Attendence::where('date', $date)
                           ->get();
        foreach ($data as $item){
            $employeeName = $this->fetchEmployeeName($item->employee_id);
                $item["employeeName"]=  $employeeName;
        }
        // dd($data);
        return view('attendence.all_employees_today')->with(['data'=> $data]);
    }
    public function attendenceTodaySet()
    {
        //
        $timestamp=new DateTime();
        
        $date = $timestamp->format("Y-m-d");
        $month_year = $timestamp->format("m-Y");
        $data = Attendence::where('date', $date)
                           ->get();
        foreach ($data as $item){
            $emp=$this->fetchEmployeeDetails($item->employee_id, $month_year);
            $item["employeeName"] = $emp['name'];
            $item["employeeSatStatus"] = $emp['saturday_status'];
        }
        // dd($data);
        return view('attendence.all_employee_today_set')->with(['data'=> $data]);
    }
    // Fetch Employee Name from employees
    public function fetchEmployeeName($id)
    {
        //
       $empolyeeName = Employee::select('name')->where('id', $id)->whereNull('deleted_at')->first();

       return $empolyeeName->name ?? "emp_deleted";

        
    }
    public function fetchEmployeeDetails($id, $month_year)
    {
        //
       $empolyee = Employee::select('name' )->where('id', $id)->whereNull('deleted_at')->first();
       $empolyeeMonth = EmployeeMonths::select('saturday_status')
                                      ->where('id', $id)
                                      ->where('month_year', $month_year)
                                      ->first();
        // dd($empolyeeMonth->saturday_status);
        $result = [
            "name"=>$empolyee->name ?? "emp_deleted",
            "saturday_status" =>$empolyeeMonth->saturday_status ?? "",
        ];
       return $result;

        
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $attendence = Attendence::where("dayTimestamp", $id)
                                ->where("employee_id", $request->emp_id)    
                ->update([
            "arrival"=>$request->arrival ?? "",
            "break"=>$request->break ?? "",
            "departure"=>$request->departure ??"",
            "worked"=>$request->worked ?? "",
            "overtime"=>$request->overtime ??"",
            "comment"=>$request->comment ?? "",
            "absent"=>"",
            "updated_at"=>now(),
            
        ]);
         return $attendence ? "true" : "false"; 
    }

    public function setAbsent(Request $request, $id)
    {
        $attendence = Attendence::where("dayTimestamp", $id)
                                ->where("employee_id", $request->emp_id)  
                ->update([
            "arrival"=>"",
            "break"=>"",
            "departure"=>"",
            "worked"=>"",
            "overtime"=>"",
            "absent"=>"true",
            "comment"=>$request->comment ?? "",
            "updated_at"=>now(),
        ]);
         return $attendence ? "true" : "false"; 
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
